@@ -252,9 +252,6 @@ typedef struct
 
 sStatments* sStatments_new();
 void sStatments_delete(sStatments* self);
-int run(sStatments* statments, char* title, sWFd* pipeout, sRFd* pipein, int pipeerr, BOOL finaly_exec, BOOL in_loop, BOOL* return_, vector_obj* blocks);
-    // saphire_compile2でコンパイルしたコンパイル結果を実行する。
-    // verboseは実行する前に実行するコマンド名を表示するかどうか
 BOOL saphire_compile2(char* cmdline, char* fname, sStatments* statments);
     // cmdlineのソースをコンパイルして結果をstatmentsに格納する。
     // コンパイル結果のstatmentsはsaphire_runによって実行できる。
